@@ -34,6 +34,7 @@ prm_qq <- function(xpdb,
                    title    = 'QQ plot of parameters | @run',
                    subtitle = 'Based on @nind individuals',
                    caption  = '@dir',
+                   tag      = NULL,
                    log      = NULL,
                    guide    = TRUE,
                    facets,
@@ -65,7 +66,7 @@ prm_qq <- function(xpdb,
            xscale = check_scales('x', log), 
            yscale = check_scales('y', log), 
            title = title, subtitle = subtitle, caption = caption,
-           plot_name = as.character(match.call()[[1]]), 
+           tag = tag, plot_name = as.character(match.call()[[1]]), 
            xscale_name = 'Quantiles of normal', 
            yscale_name = 'Quantiles of parameter', ...)
 }
@@ -79,6 +80,7 @@ eta_qq <- function(xpdb,
                    title    = 'QQ plot of etas | @run',
                    subtitle = 'Based on @nind individuals, Eta shrink: @etashk',
                    caption  = '@dir',
+                   tag      = NULL,
                    log      = NULL,
                    guide    = TRUE,
                    facets,
@@ -116,7 +118,7 @@ eta_qq <- function(xpdb,
            xscale = check_scales('x', log), 
            yscale = check_scales('y', log), 
            title = title, subtitle = subtitle, caption = caption,
-           plot_name = as.character(match.call()[[1]]), 
+           tag = tag, plot_name = as.character(match.call()[[1]]), 
            xscale_name = 'Quantiles of normal', 
            yscale_name = 'Quantiles of eta', ...)
 }
@@ -131,6 +133,7 @@ res_qq <- function(xpdb,
                    title    = 'QQ plot of @sample | @run',
                    subtitle = 'Based on @nobs observations',
                    caption  = '@dir',
+                   tag      = NULL,
                    log      = NULL,
                    guide    = TRUE,
                    facets,
@@ -168,7 +171,7 @@ res_qq <- function(xpdb,
            xscale = check_scales('x', log), 
            yscale = check_scales('y', log), 
            title = title, subtitle = subtitle, caption = caption,
-           plot_name = as.character(match.call()[[1]]), ...) +
+           tag = tag, plot_name = as.character(match.call()[[1]]), ...) +
     labs(x = 'Quantiles of normal', 
          y = 'Quantiles of @sample')
 }
@@ -182,6 +185,7 @@ cov_qq <- function(xpdb,
                    title    = 'QQ plot of continuous covariates | @run',
                    subtitle = 'Based on @nind individuals',
                    caption  = '@dir',
+                   tag      = NULL,
                    log      = NULL,
                    guide    = TRUE,
                    facets,
@@ -213,7 +217,7 @@ cov_qq <- function(xpdb,
            xscale = check_scales('x', log), 
            yscale = check_scales('y', log), 
            title = title, subtitle = subtitle, caption = caption,
-           plot_name = as.character(match.call()[[1]]), 
+           tag = tag, plot_name = as.character(match.call()[[1]]), 
            xscale_name = 'Quantiles of normal', 
            yscale_name = 'Quantiles of covariate', ...)
 }
